<?php

    //                    __ _       
    //    ___ ___  _ __  / _(_) __ _ 
    //   / __/ _ \| '_ \| |_| |/ _` |
    //  | (_| (_) | | | |  _| | (_| |
    //   \___\___/|_| |_|_| |_|\__, |
    //                         |___/ 
    //  
    // =====================================================================
    //  Create or edit configuration settings for the LIGHTBOX utility.
    //  Presently, it handles JPG, JPEG, PNG and GIF files.  The thumbnails
    //  it writes are always JPG files.
    //                                           H Marc Lewis -- March-2011
    // =====================================================================


//showParms(false);

    // ------------------------------------------------------
    // First make sure we can write to the current directory,
    // and to the thumb directory, read from tools/ and
    // that the 'GD' library is present, etc.
    // ------------------------------------------------------
    checkCapabilities();    // exits with error msg if problems found

//foreach($_SERVER as $key => $val)
//print "$key => $val<br>";

    ini_set('display_errors',1);
    // -------------------------------------------------------
    // If a file called tools/PUBLISHED exists, then don't configure
    // -------------------------------------------------------
    if (file_exists("tools/PUBLISHED")) {
        header("Location: index.php");
        exit(0);
        }

    // ------------------------------------------------------------------
    // Get FORM variables (which won't be there there on the first entry)
    // ------------------------------------------------------------------
    umask(0);
    $version    = "1.1";
    $self       = $_SERVER['PHP_SELF'];
    $Background = getPOST('Background');
    $BodyText   = getPOST('BodyText');
    $Border     = getPOST('Border');
    $Configure  = getPOST('Configure');  // Only non-empty if FORM was submitted
    $Copyright  = getPOST('Copyright');
    $Fonts      = getPOST('Fonts');
    $FontSize   = getPOST('FontSize');
    $Height     = getPOST('Height');
    $NameColor  = getPOST('NameColor');
    $PageColor  = getPOST('PageColor');
    $Publish    = getPOST('Publish');
    $Quality    = getPOST('Quality');
    $RepeatX    = getPOST('RepeatX');
    $RepeatY    = getPOST('RepeatY');
    $Spacing    = getPOST('Spacing');
    $ShowName   = getPOST('ShowName');
    $Title      = getPOST('Title');
    $TitleColor = getPOST('TitleColor');
    $TitleFont  = getPOST('TitleFont');

    if (empty($Configure)) {
        // ----------------------------------------------------------------
        // No FORM submission, first look for previous values in CONFIGURED
        // ----------------------------------------------------------------
        ini_set('display_errors',0);    // In case file doesn't exist
        $str = file_get_contents("tools/CONFIGURED");
        ini_set('display_errors',1);
        if (!empty($str)) {
            // -----------------------------------------------
            // Not first entry, get setup from CONFIGURED file
            // -----------------------------------------------
            $Args       = unserialize($str);
            $Background = $Args['Background'];
            $BodyText   = $Args['BodyText'];
            $Border     = $Args['Border'];
            $Copyright  = $Args['Copyright'];
            $Fonts      = $Args['Fonts'];
            $FontSize   = $Args['FontSize'];
            $Height     = $Args['Height'];
            $NameColor  = $Args['NameColor'];
            $PageColor  = $Args['PageColor'];
            $Publish    = $Args['Publish'];
            $Quality    = $Args['Quality'];
            $RepeatX    = $Args['RepeatX'];
            $RepeatY    = $Args['RepeatY'];
            $Spacing    = $Args['Spacing'];
            $ShowName   = $Args['ShowName'];
            $Title      = $Args['Title'];
            $TitleColor = $Args['TitleColor'];
            $TitleFont  = $Args['TitleFont'];
            }
        else {
            // --------------------------------------------------
            // First entry, no CONFIGURED file, set some defaults
            // --------------------------------------------------
            $Background = "tools/gray-grad.gif";
            $BodyText   = "Put some text here, or remove this during configuration...";
            $Border     = 1;
            $Copyright  = "";
            $Fonts      = "Verdana, Arial, 'sans serif'";
            $FontSize   = "12pt";
            $Height     = 120;
            $NameColor  = "#900";
            $PageColor  = "white";
            $Publish    = "";
            $Quality    = 75;
            $RepeatX    = "checked";
            $RepeatY    = "";
            $Spacing    = "1em";
            $SnowName   = 0;
            $TitleColor = "#900";
            $TitleFont  = "Georgia, Arial, 'sans serif'";
            $Title      = "Lewis&prime; LightBox";
            }
        }

    // ------------------------------------------------------------------------
    // FORM submission, so build the thumbnails, (re)write the CONFIGURED file,
    // conditionally write the tools/PUBLISHED file and redirect to index.php
    // ------------------------------------------------------------------------
    else {
        makeThumbs($Height,$Quality);
        $Args = Array();
//foreach ($Args as $key => $val)
//print "$key => '$val'<br>\n";
//exit(0);
        $Args['Background'] = $Background;
        $Args['BodyText']   = $BodyText;
        $Args['Border']     = $Border;
        $Args['Copyright']  = $Copyright;
        $Args['Fonts']      = $Fonts;
        $Args['FontSize']   = $FontSize;
        $Args['Height']     = $Height;
        $Args['NameColor']  = $NameColor;
        $Args['PageColor']  = $PageColor;
        $Args['Publish']    = $Publish;
        $Args['Quality']    = $Quality;
        $Args['RepeatX']    = $RepeatX;
        $Args['RepeatY']    = $RepeatY;
        $Args['Spacing']    = $Spacing;
        $Args['ShowName']   = $ShowName;
        $Args['Title']      = $Title;
        $Args['TitleColor'] = $TitleColor;
        $Args['TitleFont']  = $TitleFont;
        file_put_contents("tools/CONFIGURED",serialize($Args));
        if (!empty($Publish)) {
            ini_set('display_errors',0);
            touch("tools/PUBLISHED");
            }
        header("Location: index.php");
        exit(0);
        }

    // -------------------------------------------------------------
    // If we got this far, then generate the Configuration HTML page
    // using default values, or what we got from the CONFIGURED file
    // -------------------------------------------------------------
    if (empty($Quality))
        $Quality = 75;  // good compromise on quality/filesize
    if ($Border == 1)   { $B1 = "checked"; $B0 = ""; }
    else                { $B1 = "";        $B0 = "checked"; }
    if ($ShowName == 1) { $S1 = "checked"; $S0 = ""; }
    else                { $S1 = "";        $S0 = "checked"; }
    if (empty($RepeatX)) $Xon = ""; else $Xon = "checked";
    if (empty($RepeatY)) $Yon = ""; else $Yon = "checked";
    if (array_key_exists('HTTP_USER_AGENT',$_SERVER) and 
            strstr($_SERVER['HTTP_USER_AGENT'],"Macintosh")) {
        $h1font = "Papyrus, 'sans serif'";
        }
    else
        $h1font = "Georgia, Verdana, 'sans serif'";
    print <<<BODY
<!DOCTYPE html>
<html>
<head>
<meta charset="utf-8">
<meta NAME="description" CONTENT="A PHP utility to generate a pleasing 'LightBox'
    type display of thumbnails for photos in the current directory">
<meta name="copyright" content="2011 by H Marc Lewis. All rights reserved.">
<title> LightBox Configurator v1.0</title>
<script type="text/javascript"
    src="http://ajax.googleapis.com/ajax/libs/jquery/1.5/jquery.min.js">
</script>
<style type='text/css'>
body {      margin: 2em 3em;
            font-family: Verdana;
            font-size: 100%;
            }
table {     padding: 5px;
            margin: 2px;
            border: none;
            }
td {        font-family: Verdana;
            font-size: 100%;
            }
input,
textarea {  font-family: Verdana;
            font-size: 100%;
            color: #900;
            padding: 3px;
            }
fieldset {  background-color: yellow;
            background-color: #FFA;
            border-radius: 6px;
            width: 500px;
            float: left;
            margin: 1em;
            }
h1 {        font-family: $h1font; 
            color: #900;
            text-align: center;
            }
.left {     text-align: left; }
.center {   text-align: center; }
.right {    text-align: right; }
.top {      vertical-align: top; }
.middle {   vertical-align: middle; }
.bottom {   vertical-align: bottom; }

</style>
<script type='text/javascript'>
function showSpinner()
{
    var p = document.getElementById('Spinner');
    var d = document.getElementById('RedBox');
    var f = document.getElementById('Form');
    var m = document.getElementById('Donate');
    p.style.display = 'block';
    d.style.display = 'block';
    f.style.display = 'none';
    m.style.display = 'none';
}
function showHelp()
{
    var box = document.getElementById('HelpBox');
    box.style.display = 'block';
}
function hideHelp()
{
    var box = document.getElementById('HelpBox');
    box.style.display = 'none';
}
</script>
<script type="text/javascript">
    $(document).ready(function() {
        var version = '$version';
        $.get('http://software-ingenuity.com/lightbox/version.php',
              '$version',
              function(data) {
                if ($version < data) {
                    $('#vBoxData').text(data);
                    $('#vBox').show();
                    }
                });
    });
</script>
</head>

<body>

<h1> LightBox Configurator v$version</h1>

<div style='color: red; text-align: center; display: none; padding: 4px 10px;' id='vBox'>
NOTICE: Version <span id='vBoxData'></span> is now available at
<a href="http://software-ingenuity.com/lightbox/">
http://software-ingenuity.com/lightbox/</a>
</div>

<div style='border: 2px dashed #900; padding: 0.25em 0.5em; 
    background-color: #DDD; display: none;' id='HelpBox'>
<span style='color: #900;'>
If you're seeing this, you no doubt got LightBox installed properly.  So here's the deal...
</span>
<p>
By default, your Web server will look for the file "index.php" in this directory where
your photos are.  The first time you visit that directory via http://yourdomain.com/yourphotos/
(or something similar) the index.php file will load, and notice that there is no CONFIGURED
file present in the "tools" subdirectory,
so it will redirect to this page (config.php).  So far, so good.
<p>
config.php will run a few test to make sure it can read/write to the subdirectories it needs
to, and once you get past those errors (if any) you'll be here, ready to configure.  I suggest
that the first time, you just click the "Configure" button below and view the results.  
Then you can
return here via a similar (temporary) button at the top of the index.php page.
<p>
The most important thing, and the thing to configure first, is in the box labeled 
"<b>HTML Stuff</b>".  Don't check the "Publish" checkbox until you are sure you like it the
way it is and are ready to publish.  Once you do that, the only way to get back to this page is
by deleting a file in the "tools" sub-directory called "PUBLISHED".  
Without doing that, you are stuck with what you've configured thus far.
<p>
The "<b>Image Stuff</b>" box you can probably ignore unless you don't like the defaults.
You're only asked for the desired height of the images because that makes the thumbnails
wrap nicely to fit the browser's window, no matter what its size.
I do suggest you turn of the thumbnail filename display prior to publishing.
<p>
In this version, if you want the large pop-up photos to have a textual description,
create a file in the current directory with the same filename as the image file, but
with a ".txt" extension in place of the ".jpg" extension (or whatever image extension it
has).  The text from that file will appear centered below the pop-up image.
On many systems, case matters, so "Example.txt" will not be seen to go with "example.JPG".
<p>
The "<b>CSS Stuff</b>" is probably only interesting to you if you know what CSS is and want
some control over it.  I won't attempt to explain what that box contains, 'cause if you
are CSS aware, it's unnecessary &mdash; and if you aren't CSS aware, well, never mind...
<p>
My good friend Carl, whose idea this utility was, suggested some more enhancements.
But they will take a bit more work so I figure I'll just put this out there now
(Apr'11) and see if folks find it useful.  If so, then I'll improve it.  I may even
rewrite my ancient
<a href="http://micapeak.com/webshow/">WebShow</a>
utility to be similarly user-friendly (another of Carl's suggestions).
You can find my email address at this same domain (at the root directory, of course).
<p>
<span style='color: #900;'>
P.S.  This utility has enough smarts (barely) for the config.php page to check,
each time it's run, to see if there is a newer version. If so, it will tell you,
and you can safely download it from
<a href="http://software-ingenuity.com/lightbox/">http://software-ingenuity.com/lightbox/</a>
and install it here.  Might be wise to do a backup first, of course!
</span>
<p class='center'>
<input type='button' value='Close Help' onclick='return(hideHelp());'>
</div>


<form method='POST' action='$self' id='Form'>

<p style='text-align: center;'>
    <input type='submit' value='Configure' name='Configure'
        onclick='return(showSpinner());'>
    &nbsp;
    <input type='button' value='Help' name='Help'
        onclick='return(showHelp());'>

<fieldset>
<legend> <b>CSS Stuff</b> </legend>
<table>
<tr>
    <td class='right'> Page Title font: </td>
    <td> <input type='text' size='40' name='TitleFont' value="$TitleFont"> </td>
</tr>
<tr>
    <td class='right'> Title color: </td>
    <td> <input type='text' size='12' name='TitleColor' value="$TitleColor"> </td>
</tr>
<tr>
    <td class='right'> Text font: </td>
    <td> <input type='text' size='40' name='Fonts' value="$Fonts"> </td>
</tr>
<tr>
    <td class='right'> Text Font size: </td>
    <td> <input type='text' size='5' name='FontSize' value="$FontSize"> </td>
</tr>
<tr>
    <td class='right'> Page color: </td>
    <td> <input type='text' size='12' name='PageColor' value="$PageColor"> </td>
</tr>
<tr>
    <td class='right'> Background&nbsp;img: </td>
    <td>
        <input type='text' size='40' name='Background' value="$Background">
    </td>
</tr>
<tr>
    <td class='right'> &nbsp; </td>
    <td>
        <input type='checkbox' name='RepeatX' $Xon> Repeat-X &nbsp;
        <input type='checkbox' name='RepeatY' $Yon> Repeat-Y 
    </td>
</tr>
</table>
</fieldset>

<p>

<fieldset>
<legend> <b>Image Stuff</b> </legend>
<table>
<tr>
    <td class='right'> Thumbnail spacing: </td>
    <td>
        <input type='text' size='5' name='Spacing' value='$Spacing'> 
        <span style='font-size: 80%;'>(CSS units, e.g. <b>em</b>, <b>px</b>, etc.)</span>
    </td>
</tr>
<tr>
    <td class='right'> Thumbnail max. height: </td>
    <td>
        <input type='text' size='5' name='Height' value='$Height'>
        <span style='font-size: 80%;'>(pixels)</span>
    </td>
</tr>
<tr>
    <td class='right'> Thumbnail quality: </td>
    <td>
        <input type='text' size='5' name='Quality' value='$Quality'>
        <span style='font-size: 80%;'>
        (0&ndash;100 = quality/filesize)
        </span>
    </td>
</tr>
<tr>
    <td class='right top'> Thumbnail border: </td>
    <td>
        <input type='radio' name='Border' value='1' $B1> Yes &nbsp;
        <input type='radio' name='Border' value='0' $B0> No 
    </td>
</tr>
<tr>
    <td class='right top'> Show filename: </td>
    <td>
        <input type='radio' name='ShowName' value='1' $S1> Yes &nbsp;
        <input type='radio' name='ShowName' value='0' $S0> No 
    </td>
</tr>
<tr>
    <td class='right'> Filename color: </td>
    <td>
        <input type='text' size='12' name='NameColor' value='$NameColor'>
    </td>
</tr>
</table>
</fieldset>

<p>

<fieldset style='width: 700px;'>
<legend> <b>HTML Stuff</b> </legend>
<table>
<tr>
    <td class='right'> Page title: </td>
    <td> 
        <input type='text' size='30' name='Title' value='$Title'> 
    </td>
</tr>
<tr>
    <td class='right top'> Description<br>(HTML): </td>
    <td>
        <textarea rows=6 cols=70 name='BodyText'>$BodyText</textarea>
    </td>
</tr>
<tr>
    <td class='right top'> Copyright<br>(if any): </td>
    <td>
        <textarea rows=2 cols=70 name='Copyright'>$Copyright</textarea>
    </td>
</tr>
<tr>
    <td class='right top'> Publish?: </td>
    <td>
        <input type='checkbox' name='Publish' $Publish>
        <span style='font-size: 80%;'>
        (Click this box <b>only</b> when you have tested the results and are 
        absolutely positive you don't want to make any more changes.  But make sure
        you <b>do</b> check it before you publish this URL, otherwise the config.php
        page will still work and a malicous visitor can mess it up!)
        </span>
    </td>
</tr>
</table>
</fieldset>
</form>

<div style='float: left; max-width: 300px; padding: 0.25em;' id='Donate'>
If you find this tool useful, and would like to make a small contribution
to my efforts in creating it and making it available,
here's a handy PayPal button to do so:<p>
<form action="https://www.paypal.com/cgi-bin/webscr" method="post">
<input type="hidden" name="cmd" value="_s-xclick">
<input type="hidden" name="hosted_button_id" value="JRUAPMH7ASNTA">
<div class='center'>
<input type="image"
src="https://www.paypalobjects.com/WEBSCR-640-20110401-1/en_US/i/btn/btn_donateCC_LG.gif"
border="0" name="submit" alt="PayPal - The safer, easier way to pay online!">
<img alt="" border="0"
src="https://www.paypalobjects.com/WEBSCR-640-20110401-1/en_US/i/scr/pixel.gif" width="1"
height="1">
</div>
</form>
</div>



<p style='text-align: center; display: none;' id='Spinner'>
<img src='tools/busy.gif'>

<div id='RedBox' style='display: none;'>
<h2>Configuration in progress!</h2>
<div style='border: 1px solid black; background-color: green; color: white; 
            text-align: left; margin: 2em 0; padding: 6px 1em;'>
<p>
This can take awhile if there are a lot of images to be resized.
Please be patient.
When the configuration is done, you will be redirected to the thumbnail 
page.  If you want to re-configure, you must remove the file named <b>CONFIGURED</b>
from the "tools" sub-directory, otherwise this page won't work again [to prevent malicious
visitors from messing with your config].
</div>
</div>
<p> &nbsp;
<br>


</body>
</html>

BODY;


// -----------------------------------------------
//  Return a form parameter's value, if it exists
//  Otherwise return an empty string
// -----------------------------------------------
function getPOST($field)
{
    if (array_key_exists($field,$_POST))
        return $_POST[$field];
    else
        return "";
}


function makeThumbs($height,$quality)
{
    $Rotation = Array();
    if ($image = opendir(".")) {
        while ($name = readdir($image)) {
            if ('.jpg' == strtolower(substr($name,-4))
                    or '.jpeg' == strtolower(substr($name,-5))
                    or '.png' == strtolower(substr($name,-4))
                    or '.gif' == strtolower(substr($name,-4))
                    ) {
                $Rotation[] = $name;
                }
            }
        }
    if (count($Rotation)) {
        asort($Rotation);
        $first = $Rotation[0];
        foreach ($Rotation as $name) {
            resizeImage($name,$height,$quality);
            }
        }
    else
        print "Nada!";
}


function resizeImage($originalImage,$toHeight,$quality)
{
    $type = 'jpg';
    if ('.jpg' == strtolower(substr($originalImage,-4)))
        $type = 'jpg';
    if ('.jpeg' == strtolower(substr($originalImage,-5)))
        $type = 'jpg';
    if ('.png' == strtolower(substr($originalImage,-4)))
        $type = 'png';
    if ('.gif' == strtolower(substr($originalImage,-4)))
        $type = 'gif';
    // Get the original geometry and calculate scales
    list($width, $height) = getimagesize($originalImage);
//print "$originalImage -- $width x $height ==> $toHeight<br>\n";
    $scale = $toHeight / $height;
    
    // Recalculate new size with default ratio
    $new_width = round($width * $scale);
    $new_height = round($height * $scale);
//print "new_width = $new_width, new_height = $new_height, height = $toHeight<br>\n";
//print "scale = $scale<br>\n";
//exit(0);

    // Resize the original image
    $imageResized = ImageCreateTrueColor($new_width, $new_height);
    // Add transparency and white background
    $bg = ImageColorAllocateAlpha($imageResized, 255, 255, 255, 127); 
    ImageFill($imageResized, 0, 0 , $bg);

    if ($type == 'jpg') $imageTmp = imagecreatefromjpeg($originalImage);
    if ($type == 'png') $imageTmp = imagecreatefrompng($originalImage);
    if ($type == 'gif') $imageTmp = imagecreatefromgif($originalImage);
    imagecopyresampled($imageResized,$imageTmp,0,0,0,0,$new_width,$new_height,$width,$height);

    // Write all thumbnails as JPEGs...
    imagejpeg($imageResized,"thumb/$originalImage",$quality);
}

function showParms($exit = false)
{
    print "<div class='left' style='margin-left: 2em;'>\n";
    foreach ($_REQUEST as $key => $value) {
        $first2 = substr($key,0,2);
        if ($first2 != 'bb' && $first2 != '__')
            print "$key => $value<br>\n";
        }
    print "</div>\n";
    if ($exit) exit(0);
}


function checkCapabilities()
{
    ini_set('display_errors',0);
    $err = "";
    /*
    if (touch("HML-current-dir-test"))
        unlink("HML-current-dir-test");
    else
        $err .= "Can't write to current image directory!<br>";
    */
    if (touch("thumb/HML-current-dir-test"))
        unlink("thumb/HML-current-dir-test");
    else
        $err .= "Can't write to 'thumb' sub-directory!<br>";
    if (!file_get_contents("tools/blank.gif"))
        $err .= "Can't read from 'tools' sub-directory!<br>";
    if (touch("tools/HML-current-dir-test"))
        unlink("tools/HML-current-dir-test");
    else
        $err .= "Can't write to 'tools' sub-directory!<br>";
    if (!extension_loaded('GD'))
        $err .= "GD library required, but not supported by your PHP installation!<br>";
    if (!empty($err)) {
        print "<div style='text-align: center; font-size: 140%; color: #900'>"
             ."<h1>Errors</h1>$err</div>";
        exit(0);
        }
}
?>
